<?php
/*
Plugin Name: WooCommerce SG Newsletter Subscription
Description: Inscription de vos clients vers vos listes SG Autorepondeur
Version: 2.5.1
Author: Yannick Dudziak
Author URI: https://sg-autorepondeur.com
Requires at least: 3.5
Tested up to: 4.9.1

License: GNU General Public License v3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

/**
 * Localisation
 */
load_plugin_textdomain( 'wc_sg', false, dirname( plugin_basename( __FILE__ ) ) . '/' );


/**
 * woocommerce_sg class
 */
if ( !class_exists( 'woocommerce_sg' ) ) {
    class woocommerce_sg {
        var $adminOptionsName = 'woo_sg_settings';
        /**
         * __construct function.
         *
         * @access public
         */
        public function __construct() {
            // Add tab to woocommerce settings
            add_action( 'woocommerce_settings_tabs', array( $this, 'settings_menu' ) );
            add_action( 'woocommerce_settings_tabs_woo_sg', array( $this, 'settings' ) );
            add_action( 'woocommerce_update_options_woo_sg', array( $this, 'settings_update' ) );

            // Add frontend field
            add_action( 'woocommerce_order_status_changed', array( $this, 'process_sg_field' ), 5, 2 );
        }


        /**
         * settings_menu function.
         *
         * @access public
         * @return void
         */
        function settings_menu() {
            $currentTab = ( isset( $_GET['tab'] ) ) ? $_GET['tab'] : 'general';
            $name       = 'woo_sg';
            $label      = __( 'SG', 'wc_sg' );
            $adminUrl   = admin_url( 'admin.php?page=wc-settings&tab=' . $name );
            $active     = ( $currentTab == $name ) ? 'nav-tab-active' : '';

            echo "<a href='$adminUrl' class='nav-tab $active'>$label</a>";
        }


        /**
         * settings function.
         *
         * @access public
         * @return void
         */
        function settings() {
            include( 'templates/settings.php' );
        }


        /**
         * settings_update function.
         *
         * @access public
         * @return void
         */
        function settings_update() {
            $admin_options = get_option($this->adminOptionsName);

            $admin_options['membreid']          = filter_input(INPUT_POST, 'wc_sg_membreid', FILTER_VALIDATE_INT);
            $admin_options['listeid']           = filter_input(INPUT_POST, 'wc_sg_listeid', FILTER_VALIDATE_INT);
            $admin_options['codeactivation']    = filter_input(INPUT_POST, 'wc_sg_codeactivation', FILTER_SANITIZE_STRING);


            $args = array( 'post_type' => 'product', 'posts_per_page' => 1000 );
            $loop = new WP_Query( $args );

            foreach ($loop->posts as $post){
                $admin_options["liste_produit_{$post->ID}"] = filter_input(INPUT_POST, "wc_sg_liste_produit_{$post->ID}", FILTER_VALIDATE_INT);
            }

            update_option($this->adminOptionsName, $admin_options);
        }

        /**
         * process_sg_field function.
         *
         * @access public
         * @param int $order_id
         * @return void
         */
        function process_sg_field($order_id) {

            $admin_options = get_option($this->adminOptionsName);

            if (!isset($admin_options['membreid']) or !$admin_options['membreid'])
                return;
            if (!isset($admin_options['listeid']) or !$admin_options['listeid'])
                return;
            if (!isset($admin_options['codeactivation']) or !$admin_options['codeactivation'])
                return;

            $listeid    = $admin_options['listeid'];
            $membreid   = $admin_options['membreid'];
            $activation = $admin_options['codeactivation'];
            $array_auth = array(
                'completed' => "terminee",
                'on-hold'   => "attentePaiement",
                'pending'   => "suspendue",
                'cancelled' => "arretee",
                'refunded'  => "remboursee",
                'failed'    => "echouee",
                'processing'=> "enCours"
            );

            if($fp){
                fwrite($fp, "Liste primaire : $listeid\n");
            }

            $order = new WC_Order($order_id);

            if (!$order) {
                if($fp){
                    fwrite($fp, "La commande $order_id n'existe pas\n");
                }
                return;
            }
            $items = $order->get_items();
            $args = array( 'post_type' => 'product', 'posts_per_page' => 1000 );
            $loop = new WP_Query( $args );

            foreach($items as $item){
                foreach ($loop->posts as $loop_post){
                    if($item['product_id'] == $loop_post->ID){
                        $liste_finale = (!empty($admin_options["liste_produit_{$loop_post->ID}"])) ? $admin_options["liste_produit_{$loop_post->ID}"] : $listeid ;
                    }
                }

                $liste_finale = (isset($liste_finale) and !empty($liste_finale)) ? $liste_finale : $listeid;

                if (!array_key_exists($order->get_status(), $array_auth)) {
                    continue;
                }

                $datas = array(
                    'membreid'              => $membreid,
                    'codeactivationclient'  => $activation,
                    'listeid'               => $liste_finale,
                    'inscription_normale'   => 'non',

                    'email'                 => "{$order->get_billing_email()}",
                    'prenom'                => $order->get_shipping_first_name() ? "{$order->get_shipping_first_name()}" : "{$order->get_billing_first_name()}",
                    'nom'                   => $order->get_shipping_last_name() ? "{$order->get_shipping_last_name()}" : "{$order->get_billing_last_name()}",
                    'adresse'               => $order->get_shipping_address_1() ? "{$order->get_shipping_address_1()} {$order->get_shipping_address_2()}" : "{$order->get_billing_address_1()} {$order->get_billing_address_2()}",
                    'codepostal'            => $order->get_shipping_postcode() ? "{$order->get_shipping_postcode()}" : "{$order->get_billing_postcode()}",
                    'ville'                 => $order->get_shipping_city() ? "{$order->get_shipping_city()}" : "{$order->get_billing_city()}",
                    'pays'                  => $order->get_shipping_country() ? "{$order->get_shipping_country()}" : "{$order->get_billing_country()}",
                    'telephone'             => "{$order->get_billing_phone()}",
                    'ip'                    => "{$order->get_customer_ip_address()}",

                    'champs_1'              => $order->get_shipping_company() ? "{$order->get_shipping_company()}" : "{$order->get_billing_company()}",
                    'champs_2'              => "{$order->get_total()}",
                    'champs_3'              => "{$order->get_payment_method()}",
                    'champs_4'              => "{$order->get_payment_method_title()}",

                    'champs_10'             => $item['product_id'],
                    'champs_11'             => $item['name'],
                    'champs_12'             => $array_auth[$order->get_status()],
                );

	            wp_remote_post( 'https://sg-autorepondeur.com/inscr_decrypt.php', [
			            'method'        => 'POST',
			            'timeout'       => 45,
			            'redirection'   => 5,
			            'httpversion'   => '1.0',
			            'blocking'      => true,
			            'headers'       => array(),
			            'body'          => $datas,
			            'cookies'       => array()
		            ]
	            );
            }
            return;
        }
    } // End Class
    // Instantiate the class
    global $woocommerce_sg;
    $woocommerce_sg = new woocommerce_sg();
}